%define upstream_name    AnyData
%define upstream_version 0.12

%{?perl_default_filter}

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 8

Summary:    Easy access to data in many formats
License:    GPL+ or Artistic
Group:      Development/Perl
Url:        https://metacpan.org/release/%{upstream_name}
Source0:    https://cpan.metacpan.org/authors/id/J/JZ/JZUCKER/%{upstream_name}-%{upstream_version}.tar.gz

BuildRequires: perl(CGI)
BuildRequires: perl(ExtUtils::MakeMaker) >= 6.300.0
BuildRequires: perl(Test::More) >= 0.900.0
BuildRequires: perl(Test::Output) >= 0.10.0
BuildArch:  noarch

%description
The rather wacky idea behind this module and its sister module DBD::AnyData is
that any data, regardless of source or format should be accessible and
modifiable with the same simple set of methods. This module provides a
multi-dimensional tied hash interface to data in a dozen different formats. The
DBD::AnyData module adds a DBI/SQL interface for those same formats.

Both modules provide built-in protections including appropriate flocking() for
all I/O and (in most cases) record-at-a-time access to files rather than
slurping of entire files.

Currently supported formats include general format flatfiles (CSV, Fixed
Length, etc.), specific formats (passwd files, httpd logs, etc.), and a variety
of other kinds of formats (XML, Mp3, HTML tables). The number of supported
formats will continue to grow rapidly since there is an open API making it easy
for any author to create additional format parsers which can be plugged in to
AnyData itself and thereby be accessible by either the tiedhash or DBI/SQL
interface.

%prep
%setup -q -n %{upstream_name}-%{upstream_version}

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%make_install

%files
%doc Changes LICENSE META.json META.yml MYMETA.yml README
%dir %{perl_vendorlib}/AnyData
%dir %{perl_vendorlib}/AnyData/Storage
%dir %{perl_vendorlib}/AnyData/Format
%{perl_vendorlib}/AnyData/Storage/*
%{perl_vendorlib}/AnyData/Format/*
%{perl_vendorlib}/*.pm
%{_mandir}/*/*


%changelog
* Fri Jun 27 2025 umeabot <umeabot> 0.120.0-8.mga10
+ Revision: 2208333
- Mageia 10 Mass Rebuild

* Tue Mar 22 2022 umeabot <umeabot> 0.120.0-7.mga9
+ Revision: 1818752
- Mageia 9 Mass Rebuild

* Wed Feb 12 2020 umeabot <umeabot> 0.120.0-6.mga8
+ Revision: 1503435
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%makeinstall_std

* Thu Sep 20 2018 umeabot <umeabot> 0.120.0-5.mga7
+ Revision: 1281580
- Mageia 7 Mass Rebuild

* Mon Oct 02 2017 tv <tv> 0.120.0-4.mga7
+ Revision: 1162805
- rebuild with fixed rpm for missing autodeps

* Sat Jun 18 2016 pterjan <pterjan> 0.120.0-3.mga6
+ Revision: 1022499
- Rebuild for perl 5.22.2

* Thu Feb 18 2016 umeabot <umeabot> 0.120.0-2.mga6
+ Revision: 966931
- Mageia 6 Mass Rebuild

* Sun Jun 28 2015 sander85 <sander85> 0.120.0-1.mga6
+ Revision: 847108
- update to 0.12

* Wed Oct 15 2014 umeabot <umeabot> 0.110.0-5.mga5
+ Revision: 750788
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.110.0-4.mga5
+ Revision: 683474
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 0.110.0-3.mga4
+ Revision: 509006
- Mageia 4 Mass Rebuild

* Sun Jan 13 2013 umeabot <umeabot> 0.110.0-2.mga3
+ Revision: 362928
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Jan 08 2013 jquelin <jquelin> 0.110.0-1.mga3
+ Revision: 341908
- update to 0.11

* Thu Jan 20 2011 jquelin <jquelin> 0.100.0-1.mga1
+ Revision: 25895
- no meta.yml :-(
- mageia rebuild
- imported package perl-AnyData


* Wed Jul 29 2009 Jérôme Quelin <jquelin@mandriva.org> 0.100.0-1mdv2010.0
+ Revision: 402961
- rebuild using %%perl_convert_version

* Wed Jul 23 2008 Thierry Vignaud <tv@mandriva.org> 0.10-3mdv2009.0
+ Revision: 241144
- rebuild
- kill re-definition of %%buildroot on Pixel's request

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Mon May 14 2007 Oden Eriksson <oeriksson@mandriva.com> 0.10-1mdv2008.0
+ Revision: 26654
- Import perl-AnyData



* Mon May 14 2007 Oden Eriksson <oeriksson@mandriva.com> 0.10-1
- initial Mandriva package 
